@@ -497,9 +497,7 @@ class AncSampler(DistributedSampler):
             self.indices = indices
         assert len(indices) == self.num_samples
         # further split the per rank indices into num_workers splits
-        return self._create_chunk_indices_from_bz_and_worker(
-            self.indices
-        )
+        return self._create_chunk_indices_from_bz_and_worker(self.indices)
 
     def __iter__(self):
         # do all initialization before yielding to trigger local variable recycling
